@@ -1,10 +1,8 @@
+( cd usr/X11R7/lib ; rm -rf libI810XvMC.so )
+( cd usr/X11R7/lib ; ln -sf libI810XvMC.so.1.0.0 libI810XvMC.so )
 ( cd usr/X11R7/lib ; rm -rf libI810XvMC.so.1 )
 ( cd usr/X11R7/lib ; ln -sf libI810XvMC.so.1.0.0 libI810XvMC.so.1 )
 ( cd usr/X11R7/lib ; rm -rf libIntelXvMC.so )
 ( cd usr/X11R7/lib ; ln -sf libIntelXvMC.so.1.0.0 libIntelXvMC.so )
-( cd usr/X11R7/lib/xorg/modules/drivers ; rm -rf i810_drv.so )
-( cd usr/X11R7/lib/xorg/modules/drivers ; ln -sf intel_drv.so i810_drv.so )
-( cd usr/X11R7/lib ; rm -rf libI810XvMC.so )
-( cd usr/X11R7/lib ; ln -sf libI810XvMC.so.1.0.0 libI810XvMC.so )
 ( cd usr/X11R7/lib ; rm -rf libIntelXvMC.so.1 )
 ( cd usr/X11R7/lib ; ln -sf libIntelXvMC.so.1.0.0 libIntelXvMC.so.1 )
